netapp_ontap.models.autosupport_issues API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.autosupport_issues`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AutosupportIssuesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AutosupportIssues object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `component: str GET POST PATCH`

    The name of the component where the issue occurred.

    Valid choices:

    - https_put_destination
    - https_post_destination
    - mail_server
    - ondemand_server
  `corrective_action: AutosupportConnectivityCorrectiveAction GET POST PATCH`

    The corrective_action field of the autosupport_issues.

  `destination: str GET`

    The HTTPS/SMTP/AOD AutoSupport Destination.

    Example: mailhost1.example.com

  `issue: AutosupportConnectivityIssue GET POST PATCH`

    The issue field of the autosupport_issues.

  `node: Node GET`

    The node field of the autosupport_issues.